==> ktp-text-ui_0.8.1.orig.tar.bz2: ktp-text-ui-0.8.1/filters/latex/ktptextui_message_filter_latex.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_latex
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=latex
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KDE-PluginInfo-Weight=10
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

Name=LaTeX Renderer
Name[bs]=LaTeX Obrađivač
Name[ca]=Renderitzador LaTeX
Name[ca@valencia]=Renderitzador LaTeX
Name[cs]=Vykreslování Latex
Name[da]=LaTeX-rendering
Name[de]=LaTeX-Renderer
Name[el]=Πρόγραμμα αποτύπωσης LaTeX
Name[es]=Renderizador de LaTeX
Name[fi]=LaTeX-renderöijä
Name[fr]=Moteur de rendu LaTeX
Name[gl]=Renderizador de LaTeX
Name[hu]=LaTeX renderelő
Name[ia]=Renditor de LaTeX
Name[it]=Visualizzatore LaTeX
Name[kk]=LaTeX кескіндегіші
Name[ko]=LaTeX 렌더러
Name[nb]=LaTeX-viser
Name[nl]=LaTeX-renderer
Name[pl]=Program wyświetlający LaTeX
Name[pt]=Representação em LaTeX
Name[pt_BR]=Renderizador de LaTeX
Name[ru]=Визуализатор LaTeX
Name[sk]=Vykresľovač LaTeX
Name[sl]=Izrisovalnik za LaTeX
Name[sr]=Рендерер латеха
Name[sr@ijekavian]=Рендерер латеха
Name[sr@ijekavianlatin]=Renderer LaTeXa
Name[sr@latin]=Renderer LaTeXa
Name[sv]=Latex-återgivning
Name[tr]=LaTeX Hazırlayıcı
Name[uk]=Показ формул LaTeX
Name[x-test]=xxLaTeX Rendererxx
Name[zh_TW]=LaTeX 成像器
Comment=If incoming messages contain LaTeX between $$, it will render it directly into the chat.
Comment[bs]=Ako poruka sadrži Latex između $$, ona će se ugraditi u ćaskanje.
Comment[ca]=Si els missatges entrants conten LaTeX entre $$, es representarà directament en el xat.
Comment[ca@valencia]=Si els missatges entrants conten LaTeX entre $$, es representarà directament en el xat.
Comment[cs]=Pokud příchozí zpráva obsahuje kód latex mezi $$ bude vykreslena přímo do rozhovoru
Comment[da]=Hvis indkommende beskeder indholder LaTeX mellem $$, vil den rendere det direkte i chatten.
Comment[de]=Wenn eine eingehende Nachricht LaTeX eingeschlossenen in $$ enthält, wird sie direkt im Chat-Fenster gerendert.
Comment[el]=Αν τα εισερχόμενα μηνύματα περιέχουν LaTeX ανάμεσα σε $$, η αποτύπωση θα γίνεται απευθείας στη συνομιλία.
Comment[es]=Si un mensaje recibido contiene código LaTeX entre $$, este se renderizará directamente en el chat.
Comment[fi]=Jos saapuvissa viesteissä on LaTeX-koodia $$-merkkien välissä, se koodi renderöidään suoraan keskusteluun.
Comment[fr]=Si des messages entrants contiennent du LaTeX entre « $$ », il le rendra directement dans le forum de discussions.
Comment[gl]=Se unha mensaxe de entrada contén LaTeX entre «$$», debuxarase directamente na conversa.
Comment[hu]=Ha a bejövő üzenetek LaTeX-et tartalmaznak $$ között, akkor azok közvetlenül a csevegésben lesznek renderelve.
Comment[ia]=Si messages in arrivata contine LaTeX intra $$, illo essera rendite directemente in le conversation.
Comment[it]=Se in un messaggio c'è codice LaTeX dentro $$...$$, sarà visualizzato direttamente nella finestra di chat
Comment[kk]=Егер кіріс хабарламада $$ де қоршалған LaTex болса, ол чатта тікелей кескінделеді.
Comment[ko]=받은 메시지의 $$ 사이에 LaTeX 수식이 있으면 대화 창에 표시합니다.
Comment[nb]=Hvis innkommende meldinger inneholder LaTeX-kode mellom $$ så blir den tegnet opp direkte i praten.
Comment[nl]=Als een inkomend bericht LaTeX tussen $$ bevat, zal het direct in de chat worden weergegeven
Comment[pl]=Jeśli przychodząca wiadomość zawiera LaTeX pomiędzy $$, to  zostanie ona wyświetlona bezpośrednio w rozmowie.
Comment[pt]=Se as mensagens recebidas tiverem código em LaTeX entre $$, o mesmo será desenhado directamente na conversa.
Comment[pt_BR]=Se existir código em LaTeX entre $$ nas mensagens recebidas, ele será mostrado no bate-papo.
Comment[ru]=Если входящие сообщения содержат код LaTeX между символами $$, он будет отрисован в чате.
Comment[sk]=Ak prichádzajúca správa obsahuje LaTeX medzi $$, vykreslí to rovno do rozhovoru.
Comment[sl]=Če bo katerokoli dohodno sporočilo vsebovalo LaTeX med $$, bo samodejno izrisan v klepetu.
Comment[sr]=Када долазна порука садржи латех између $$, биће рендерован непосредно у ћаскање.
Comment[sr@ijekavian]=Када долазна порука садржи латех између $$, биће рендерован непосредно у ћаскање.
Comment[sr@ijekavianlatin]=Kada dolazna poruka sadrži LaTeX između $$, biće renderovan neposredno u ćaskanje.
Comment[sr@latin]=Kada dolazna poruka sadrži LaTeX između $$, biće renderovan neposredno u ćaskanje.
Comment[sv]=Om inkommande meddelande innehåller Latex mellan $$, återges den direkt i chatten.
Comment[tr]=Eğer gelen iletiler $$ arasında LaTeX içeriyorsa, sohbette doğrudan hazırlanacak.
Comment[uk]=Якщо у будь-якому з повідомлень містяться формули LaTeX, обмежені символами $$, їхнє зображення буде вбудовано безпосередньо до панелі спілкування.
Comment[x-test]=xxIf incoming messages contain LaTeX between $$, it will render it directly into the chat.xx
Comment[zh_TW]=如果進來的訊息包含用 $$ 包起來的 LaTeX 語法，則會直接將它成像在聊天室中。

==> ktp-text-ui-0.8.80.tar.bz2: ktp-text-ui-0.8.80/filters/latex/ktptextui_message_filter_latex.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_latex
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=latex
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KDE-PluginInfo-Weight=10
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

Name=LaTeX Renderer
Name[bs]=LaTeX Renderer
Name[ca]=Renderitzador LaTeX
Name[ca@valencia]=Renderitzador LaTeX
Name[cs]=Vykreslování Latex
Name[da]=LaTeX-rendering
Name[de]=LaTeX-Renderer
Name[el]=Πρόγραμμα αποτύπωσης LaTeX
Name[en_GB]=LaTeX Renderer
Name[es]=Renderizador de LaTeX
Name[et]=LaTeXi renderdaja
Name[fi]=LaTeX-renderöijä
Name[fr]=Moteur de rendu LaTeX
Name[gl]=Renderizador de LaTeX
Name[hu]=LaTeX renderelő
Name[ia]=Renditor de LaTeX
Name[it]=Visualizzatore LaTeX
Name[kk]=LaTeX кескіндегіші
Name[ko]=LaTeX 렌더러
Name[lt]=LaTeX pateikimas
Name[nb]=LaTeX-viser
Name[nds]=LaTeX-Wieser
Name[nl]=LaTeX-renderer
Name[pa]=LaTeX ਰੈਂਡਰ
Name[pl]=Wyświetlanie LaTeX
Name[pt]=Representação em LaTeX
Name[pt_BR]=Renderizador de LaTeX
Name[ro]=Randor LaTeX
Name[ru]=Визуализатор LaTeX
Name[sk]=Vykresľovač LaTeX
Name[sl]=Izrisovalnik za LaTeX
Name[sr]=Рендерер латеха
Name[sr@ijekavian]=Рендерер латеха
Name[sr@ijekavianlatin]=Renderer LaTeXa
Name[sr@latin]=Renderer LaTeXa
Name[sv]=Latex-återgivning
Name[tr]=LaTeX Hazırlayıcı
Name[uk]=Показ формул LaTeX
Name[x-test]=xxLaTeX Rendererxx
Name[zh_CN]=LaTeX 渲染器
Name[zh_TW]=LaTeX 成像器
Comment=If incoming messages contain LaTeX between $$, it will render it directly into the chat.
Comment[bs]=Ako dolazne poruke sadrže LaTeX između $$, crtaće se direktno u ćaskanju.
Comment[ca]=Si els missatges entrants conten LaTeX entre $$, es representarà directament en el xat.
Comment[ca@valencia]=Si els missatges entrants conten LaTeX entre $$, es representarà directament en el xat.
Comment[cs]=Pokud příchozí zpráva obsahuje kód latex mezi $$ bude vykreslena přímo do rozhovoru
Comment[da]=Hvis indkommende beskeder indholder LaTeX mellem $$, vil den rendere det direkte i chatten.
Comment[de]=Wenn eine eingehende Nachricht LaTeX eingeschlossenen in $$ enthält, wird sie direkt im Chat-Fenster gerendert.
Comment[el]=Αν τα εισερχόμενα μηνύματα περιέχουν LaTeX ανάμεσα σε $$, η αποτύπωση θα γίνεται απευθείας στη συνομιλία.
Comment[en_GB]=If incoming messages contain LaTeX between $$, it will render it directly into the chat.
Comment[es]=Si un mensaje recibido contiene código LaTeX entre $$, este se renderizará directamente en el chat.
Comment[et]=Kui sisenevas sõnumis esineb $$ vahel LaTeX, renderdatakse see otse vestluses
Comment[fi]=Jos saapuvissa viesteissä on LaTeX-koodia $$-merkkien välissä, se koodi renderöidään suoraan keskusteluun.
Comment[fr]=Si des messages entrants contiennent du LaTeX entre « $$ », il l'affichera directement dans la discussion.
Comment[gl]=Se unha mensaxe de entrada contén LaTeX entre «$$», debuxarase directamente na conversa.
Comment[hu]=Ha a bejövő üzenetek LaTeX-et tartalmaznak $$ között, akkor azok közvetlenül a csevegésben lesznek renderelve.
Comment[ia]=Si messages in arrivata contine  LaTeX $$, illo essera rendite directemente in le conversation.
Comment[it]=Se in un messaggio c'è codice LaTeX dentro $$...$$, sarà visualizzato direttamente nella finestra di chat
Comment[kk]=Егер кіріс хабарламада $$ де қоршалған LaTex болса, ол чатта тікелей кескінделеді.
Comment[ko]=받은 메시지의 $$ 사이에 LaTeX 수식이 있으면 대화 창에 표시합니다.
Comment[lt]=Jei gautos žinutės turi LaTeX tarp $$, jis bus išvestas tiesiai į pokalbį
Comment[nb]=Hvis innkommende meldinger inneholder LaTeX-kode mellom $$ så blir den tegnet opp direkte i praten.
Comment[nds]=Bargt rinkamen Narichten LaTeX twischen $-Tekens, warrt dat direktemang binnen den Klöönsnack wiest
Comment[nl]=Als een inkomend bericht LaTeX tussen $$ bevat, zal het direct in de chat worden weergegeven
Comment[pl]=Jeśli przychodząca wiadomość będzie zawierać składnię LaTeX pomiędzy $$, to zostanie ona wyświetlona bezpośrednio w rozmowie.
Comment[pt]=Se as mensagens recebidas tiverem código em LaTeX entre $$, o mesmo será desenhado directamente na conversa.
Comment[pt_BR]=Se existir código em LaTeX entre $$ nas mensagens recebidas, ele será mostrado no bate-papo.
Comment[ru]=Если входящие сообщения содержат код LaTeX между символами $$, он будет отрисован в чате.
Comment[sk]=Ak prichádzajúca správa obsahuje LaTeX medzi $$, vykreslí to rovno do rozhovoru.
Comment[sl]=Če bo katerokoli dohodno sporočilo vsebovalo LaTeX med $$, bo samodejno izrisan v klepetu.
Comment[sr]=Када долазна порука садржи латех између $$, биће рендерован непосредно у ћаскање.
Comment[sr@ijekavian]=Када долазна порука садржи латех између $$, биће рендерован непосредно у ћаскање.
Comment[sr@ijekavianlatin]=Kada dolazna poruka sadrži LaTeX između $$, biće renderovan neposredno u ćaskanje.
Comment[sr@latin]=Kada dolazna poruka sadrži LaTeX između $$, biće renderovan neposredno u ćaskanje.
Comment[sv]=Om inkommande meddelande innehåller Latex mellan $$, återges den direkt i chatten.
Comment[tr]=Eğer gelen iletiler $$ arasında LaTeX içeriyorsa, sohbette doğrudan hazırlanacak.
Comment[uk]=Якщо у будь-якому з повідомлень містяться формули LaTeX, обмежені символами $$, їхнє зображення буде вбудовано безпосередньо до панелі спілкування.
Comment[x-test]=xxIf incoming messages contain LaTeX between $$, it will render it directly into the chat.xx
Comment[zh_CN]=如果任何消息在 $$ 之间包含了 LaTeX 命令，它将会直接显示于聊天窗口中。
Comment[zh_TW]=如果進來的訊息包含在 $$ 間的 LaTex 語法，它會直接在聊天視窗中成像。
